==> otrs-3.0.3.tar.bz2: otrs-3.0.3/bin/fcgi-bin/customer.pl <==
#!/usr/bin/perl -w
# --
# bin/fcgi-bin/customer.pl - the global FCGI handle file (incl. auth) for OTRS
# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
# --
# $Id: customer.pl,v 1.2 2009/12/02 08:43:54 mb Exp $
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

# use ../../ as lib location
use FindBin qw($Bin);
use lib "$Bin/../..";
use lib "$Bin/../../Kernel/cpan-lib";

use vars qw(@ISA $VERSION);
$VERSION = qw($Revision: 1.2 $)[1];

# check @INC for mod_perl (add lib path for "require module"!)
push (@INC, "$Bin/../..", "$Bin/../../Kernel/cpan-lib");

# Imports the library; required line
use CGI::Fast;

# load agent web interface
use Kernel::System::Web::InterfaceCustomer();

# 0=off;1=on;
my $Debug = 0;
#my $Cnt = 0;

# Response loop
while (my $WebRequest = new CGI::Fast) {
    # create new object
    my $Interface = Kernel::System::Web::InterfaceCustomer->new(Debug => $Debug, WebRequest => $WebRequest);

    # execute object
    $Interface->Run();
#    $Cnt++;
#    print STDERR "This is connection number $Cnt\n";
}

==> otrs-4.0.16.tar.bz2: otrs-4.0.16/bin/fcgi-bin/customer.pl <==
#!/usr/bin/perl
# --
# bin/fcgi-bin/customer.pl - the global FCGI handle file (incl. auth) for OTRS
# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

# use ../../ as lib location
use FindBin qw($Bin);
use lib "$Bin/../..";
use lib "$Bin/../../Kernel/cpan-lib";
use lib "$Bin/../../Custom";

# Imports the library; required line
use CGI::Fast;

# load customer web interface
use Kernel::System::Web::InterfaceCustomer();
use Kernel::System::ObjectManager;

# 0=off;1=on;
my $Debug = 0;

#my $Cnt = 0;

# Response loop
while ( my $WebRequest = new CGI::Fast ) {

    local $Kernel::OM = Kernel::System::ObjectManager->new();
    my $Interface = Kernel::System::Web::InterfaceCustomer->new(
        Debug      => $Debug,
        WebRequest => $WebRequest,
    );
    $Interface->Run();

    #    $Cnt++;
    #    print STDERR "This is connection number $Cnt\n";
}
